summary refs log tree commit diff
diff options
context:
space:
mode:
authorEfraim Flashner <efraim@flashner.co.il>2020-06-03 12:43:04 +0300
committerEfraim Flashner <efraim@flashner.co.il>2020-06-03 12:43:04 +0300
commit683910e9834f6e83fc3c291f129e8c9f72cf595a (patch)
tree9ffab1c74f2890e55729c2aa6ec5f53e19ba5dec
parent9ab2790e2acf872c0f2cf41ec180de80d1eee3f3 (diff)
downloadguix-683910e9834f6e83fc3c291f129e8c9f72cf595a.tar.gz
gnu: global: Move vim plugins to correct directory.
* gnu/packages/code.scm (global)[arguments]: Adjust 'post-install phase
to install vim plugin files to the expected directory.
-rw-r--r--gnu/packages/code.scm15
1 files changed, 11 insertions, 4 deletions
diff --git a/gnu/packages/code.scm b/gnu/packages/code.scm
index a50ac3506a..f6aaa63853 100644
--- a/gnu/packages/code.scm
+++ b/gnu/packages/code.scm
@@ -2,7 +2,7 @@
 ;;; Copyright © 2013, 2015, 2018 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright © 2015 Andreas Enge <andreas@enge.fr>
 ;;; Copyright © 2015, 2018 Ricardo Wurmus <rekado@elephly.net>
-;;; Copyright © 2016, 2017, 2019 Efraim Flashner <efraim@flashner.co.il>
+;;; Copyright © 2016, 2017, 2019, 2020 Efraim Flashner <efraim@flashner.co.il>
 ;;; Copyright © 2017, 2018, 2019, 2020 Tobias Geerinckx-Rice <me@tobias.gr>
 ;;; Copyright © 2017, 2018 Clément Lassieur <clement@lassieur.org>
 ;;; Copyright © 2017 Andy Wingo <wingo@igalia.com>
@@ -146,12 +146,19 @@ highlighting your own code that seemed comprehensible when you wrote it.")
        (modify-phases %standard-phases
         (add-after 'install 'post-install
           (lambda* (#:key outputs #:allow-other-keys)
             ;; Install the Emacs Lisp file in the right place.
             (let* ((out  (assoc-ref outputs "out"))
                    (data (string-append out "/share/gtags"))
+                   (vim  (string-append out "/share/vim/vimfiles/plugin"))
                    (lisp (string-append out "/share/emacs/site-lisp")))
-              (install-file (string-append data "/gtags.el") lisp)
-              (delete-file (string-append data "/gtags.el"))
+              (mkdir-p lisp)
+              (mkdir-p vim)
+              (rename-file (string-append data "/gtags.el")
+                           (string-append lisp "/gtags.el"))
+              (rename-file (string-append data "/gtags.vim")
+                           (string-append vim "/gtags.vim"))
+              (rename-file (string-append data "/gtags-cscope.vim")
+                           (string-append vim "/gtags-cscope.vim"))
               #t))))))
     (home-page "https://www.gnu.org/software/global/")
     (synopsis "Cross-environment source code tag system")
@@ -146,12 +146,19 @@ highlighting your own code that seemed comprehensible when you wrote it.")
         (add-after 'install 'post-install
           (lambda* (#:key outputs #:allow-other-keys)
-            ;; Install the Emacs Lisp file in the right place.
+            ;; Install the plugin files in the right place.
             (let* ((out  (assoc-ref outputs "out"))
                    (data (string-append out "/share/gtags"))